@@ -9,11 +9,15 @@ use std::{
     sync::Mutex,
 };
 
+#[allow(unknown_lints)]
+#[allow(nonreentrant_function_in_test)]
 #[test]
 fn no_write() {
     test(false, 0);
 }
 
+#[allow(unknown_lints)]
+#[allow(nonreentrant_function_in_test)]
 #[test]
 fn write() {
     test(true, 1);
@@ -33,6 +37,9 @@ fn test(write: bool, n: usize) {
 
     let corpus = corpus_directory_from_target("hello-world", "target");
 
+    // smoelius: This call to `remove_dir_all` is protected by the mutex above.
+    #[allow(unknown_lints)]
+    #[allow(nonreentrant_function_in_test)]
     remove_dir_all(&corpus).unwrap_or_default();
 
     let mut command = Command::cargo_bin("hello-world").unwrap();
