@@ -1,16 +1,6 @@
 use assert_cmd::Command;
-use lazy_static::lazy_static;
 use predicates::prelude::*;
-use std::path::Path;
-
-lazy_static! {
-    static ref MANIFEST_PATH: String = Path::new(env!("CARGO_MANIFEST_DIR"))
-        .join("..")
-        .join("examples")
-        .join("Cargo.toml")
-        .to_string_lossy()
-        .to_string();
-}
+use testing::examples::MANIFEST_PATH;
 
 // smoelius: This test will fail if run twice because the target will have already been built.
 #[test]
